# PYSMMS

基于 sm.ms 图床的命令行工具。

借鉴 [n0vad3v/smv2](https://github.com/n0vad3v/smv2)，在其基础上添加了上传成功后自动拷贝图片链接到剪贴板，多账号随机上传等功能。

# 安装

```bash
pip install pysmms
```

# 使用

## 查看帮助

```bash
➜  ~ pysmms help
pysmms {arg}

   profile          查看用户资料（需要配置 Authorization）
   ip_history       基于 IP 的临时上传历史记录
   history          获取用户上传记录（需要配置 Authorization）
   /path/to/picture 上传图片（需要配置 Authorization）

上传图片不需要配置 Authorization，但不保证图片的使用时效。
配置 Authorization 需要在用户根目录创建 .pysmms 文件，文件写入以下内容：

    [sm.ms]
    auth=['wKSlYH******z8eb8qSr']

注意：auth 以列表存放，支持多个 auth 随机上传。
```

## 上传图片

```bash
pysmms /path/to/picture
```

例如：

```bash
➜  ~ pysmms /Users/lijianxun/Desktop/Snip1.png
┌SM.MS - 上传成功─────────────────────────────────────────────────────────┐
│ 文件     │ Snip1.png                                                    │
├──────────┼──────────────────────────────────────────────────────────────┤
│ 图片地址 │ https://i.loli.net/2020/02/24/r18eqzSVRiHDE9v.png            │
├──────────┼──────────────────────────────────────────────────────────────┤
│ 删除     │ https://sm.ms/delete/rE9SwajhbAzXpJYgKFLOeWV4sm              │
├──────────┼──────────────────────────────────────────────────────────────┤
│ 备注     │ 此次上传携带 Authorization：ptKO9wKSlYHdzeYY1UVBYlz8eb3BeWFr │
└──────────┴──────────────────────────────────────────────────────────────┘
```